@@ -125,7 +125,7 @@ class Selection_blender(Selection, Slots_blender):
 	def setSelectionStyle(ctx):
 		'''Set the selection style context.
 
-		:Parameters:
+		Parameters:
 			ctx (str): Selection style context. valid: 'marquee', 'lasso', 'paint'.
 		'''
 		ctx = ctx+'Context'
@@ -433,7 +433,7 @@ class Selection_blender(Selection, Slots_blender):
 	def generateUniqueSetName(self, obj=None):
 		'''Generate a generic name based on the object's name.
 
-		:Parameters:
+		Parameters:
 			obj (str)(obj)(list): The maya scene object to derive a unique name from.
 
 		<objectName>_Set<int>
