@@ -104,10 +104,10 @@ class Crease_maya(Crease, Slots_maya):
 	def getCreasedEdges(self, edges):
 		'''Return any creased edges from a list of edges.
 
-		:Parameters:
+		Parameters:
 			edges (str)(obj)(list): The edges to check crease state on.
 
-		:Return:
+		Return:
 			(list) edges.
 		'''
 		creased_edges = [e for e in pm.ls(edges, flatten=1) if pm.polyCrease(e, q=1, value=1)[0] > 0]
