@@ -18,7 +18,7 @@ class Tcl_max(Tcl):
 	Parameters:
 		parent = main application top level window object.
 	'''
-	def __init__(self, parent=None, slotLoc='slots/max', *args, **kwargs):
+	def __init__(self, parent=None, slots='slots/max', *args, **kwargs):
 		'''
 		'''
 		if not parent:
@@ -28,7 +28,7 @@ class Tcl_max(Tcl):
 			except Exception as error:
 				print(__file__, error)
 
-		super().__init__(parent, slotLoc=slotLoc, *args, **kwargs)
+		super().__init__(parent, slots=slots, *args, **kwargs)
 
 
 	@classmethod
